==> google-cloud-sdk-325.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/kuberun/applications/retire.py <==
# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to retire a KubeRun application."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.kuberun import flags
from googlecloudsdk.command_lib.kuberun import kuberun_command

_DETAILED_HELP = ({
    'EXAMPLES':
        """
        To retire a KubeRun application in environment ENV, run

            $ {command} --environment ENV
        """,
})


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Retire(kuberun_command.KubeRunStreamingCommand, base.DeleteCommand):
  """Retires a KubeRun application in this directory."""

  detailed_help = _DETAILED_HELP
  flags = [flags.EnvironmentFlag()]

  @classmethod
  def Args(cls, parser):
    super(Retire, cls).Args(parser)
    base.DeleteCommand._Flags(parser)
    base.URI_FLAG.RemoveFromParser(parser)

  def Command(self):
    return ['applications', 'retire']

==> google-cloud-sdk-327.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/kuberun/applications/retire.py <==
# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to retire a KubeRun application."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.kuberun import flags
from googlecloudsdk.command_lib.kuberun import kuberun_command

_DETAILED_HELP = ({
    'EXAMPLES':
        """
        To retire a KubeRun application in environment ENV, run

            $ {command} --environment ENV
        """,
})


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Retire(kuberun_command.KubeRunCommand, base.DeleteCommand):
  """Retires a KubeRun application in this directory."""

  detailed_help = _DETAILED_HELP
  flags = [flags.EnvironmentFlag()]

  @classmethod
  def Args(cls, parser):
    super(Retire, cls).Args(parser)
    base.DeleteCommand._Flags(parser)
    base.URI_FLAG.RemoveFromParser(parser)

  def Command(self):
    return ['applications', 'retire']

  @property
  def should_stream_stdout(self):
    # TODO(b/170872460): Delete once this command stops streaming stdout.
    return True
